@@ -4,20 +4,20 @@
  * Copyright (C) 2002 Havoc Pennington
  * Copyright (C) 2002 Mathias Hasselmann
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * This file is part of gnome-terminal.
  *
- * This library is distributed in the hope that it will be useful,
+ * Gnome-terminal is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * Gnome-terminal is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "profile-editor.h"
@@ -67,10 +67,10 @@ struct _TerminalPaletteScheme
 };
 
 static TerminalPaletteScheme palette_schemes[] = {
+  { N_("Tango"), terminal_palette_tango },
   { N_("Linux console"), terminal_palette_linux },
   { N_("XTerm"), terminal_palette_xterm },
-  { N_("Rxvt"), terminal_palette_rxvt },
-  { N_("Tango"), terminal_palette_tango }
+  { N_("Rxvt"), terminal_palette_rxvt }
 };
 
 static GtkWidget* profile_editor_get_widget                  (GtkWidget       *editor,
